/*******************************************************************************
Calculator Project
Copyright 1997, 1998 R3 Software Ltd. All Rights Reserved.

<file>
$Id: CalcView.h,v 1.8 1998/12/03 08:29:39 timmy Exp $
Component:	Application
File:		CalcView.h
Summary:	Calculator GUI view.
Created:	1997.10.02
Author:		timmy
History:
1997.10.15 timmy Full engine intergration.
1997.10.14 timmy Implemented full preferences system.
1997.10.13 timmy Added MessageReceived() and Archive() interfaces.
1997.10.05 timmy Added support for mouse and key events.
                 Now builds and renders display string.
1997.10.02 timmy Added display area to view.
1997.10.02 timmy First version of fully resizable GUI.
1998.11.30 timmy Altered to use RString rather than STL (for R4 build).
</file>
*******************************************************************************/


#ifndef _CALC_VIEW_H
#define _CALC_VIEW_H


// BeOS Includes

#ifndef _RECT_H
	#include <interface/Rect.h>
#endif

#ifndef _VIEW_H
	#include <interface/View.h>
#endif

#ifndef _MESSAGE_H
	#include <app/Message.h>
#endif

#ifndef _GRAPHICS_DEFS_H
	#include <interface/GraphicsDefs.h>
#endif

#ifndef _MENU_ITEM_H
	#include <interface/MenuItem.h>
#endif


// Class Definitions

struct CalcKey {
	
	char label[8];
	char code[8];
	char keymap[4];
	uint32 flags;
	float width;
	
}; // end struct CalcKey

#pragma export on

class RString;

class CalcOptions;
class CalcOptionsWindow;

class CalcView : public BView {

	public:
		
		// ****** STATICS ******
		
		static CalcView *Instantiate(BMessage *archive);
		
		
		// ****** CREATORS ******
		
		// Constructor.
		CalcView(BRect frame,
			const char *calcDesc,
			rgb_color rgbBaseColor);

		// Construct from archive.
		CalcView(BMessage *archive);

		// Destructor.
		virtual ~CalcView();

		
		// ****** MANIPULATORS ******
		
		// Message received hook.
		virtual void MessageReceived(BMessage *message);
		
		// Render view hook.
		virtual void Draw(BRect updateRect);
		
		// Mouse button pressed hook.
		virtual void MouseDown(BPoint point);
		
		// Key depressed hook.
		virtual void KeyDown(const char *bytes, int32 numBytes);
		
		// View receives focus hook.
		virtual void MakeFocus(bool focused = true);
		
		
		// ****** ACCESSORS ******
		
		// Present about box for view (replicant).
		virtual void AboutRequested();
		
		// Archive this view.
		virtual status_t Archive(BMessage *archive, bool deep) const;
		
		// Cut contents of view to system clipboard.
		void Cut();
		
		// Copy contents of view to system clipboard.
		void Copy();
		
		// Paste contents of system clipboard to view.
		void Paste(BMessage *message);
		
	
	private:
		
		// ****** CONSTANTS ******
		enum {
			K_OPTIONS_REQUESTED =	'opts'
			}; // end enum
		
		// Parse calculator description for view.
		void ParseCalcDesc(const char *calcDesc);
		
		// Press a key, any key.
		void PressKey(int key);
		
		// Press a key by label.
		void PressKey(char *label);
		
		// Sort out the color scheme.
		void Colorize();
		
		// Evaluate current expression.
		void Evaluate();
		
		// Create pop-up menu system.
		void CreatePopUpMenu();

		int16 mCols, mRows;			// grid dimensions
		rgb_color mRGBBaseColor;	// color scheme
		rgb_color mRGBLightEdge;
		rgb_color mRGBDarkEdge;
		rgb_color mRGBDisplay;
		float mWidth, mHeight;		// view dimensions
		char *mCalcDesc;			// keypad grid
		CalcKey *mKeypad;
		RString *mDisplayText;		// display text
		BMenuItem *mAboutItem;		// pop-up context menu.
		BMenuItem *mOptionsItem;
		BPopUpMenu *mPopUpMenu;
		CalcOptions *mOptions;		// calculator options.
		CalcOptionsWindow *mOptionsWindow;
		
}; // end class CalcView

#pragma export reset


/******************************************************************************/

#endif // _CALC_VIEW_H

// end CalcView.h