/*******************************************************************************
Calculator Project
Copyright 1997, 1998 R3 Software Ltd. All Rights Reserved.

<file>
$Id: CalcWindow.cpp,v 1.6 1998/12/03 08:29:39 timmy Exp $
Component:	Application
File:		CalcWindow.cpp
Summary:	Calculator GUI window.
Created:	1997.10.02
Author:		timmy
History:
1997.10.02 timmy Now passes base colour to CalcView ctor.
1997.10.05 timmy Now makes CalcView the window focus.
1997.10.14 timmy Implemented full preferences system.
1997.10.15 timmy Full engine intergration.
</file>
*******************************************************************************/


#include "CalcWindow.h"


// Standard Includes

#include <stdlib.h>
#include <stdio.h>
#include <assert.h>


// BeOS Includes

#ifndef _APPLICATION_H
	#include <app/Application.h>
#endif

#ifndef _GRAPHICS_DEFS_H
	#include <interface/GraphicsDefs.h>
#endif

#ifndef _DRAGGER_H
	#include <interface/Dragger.h>
#endif


// Application Includes

#ifndef _CALC_VIEW_H
	#include "CalcView.h"
#endif


// Code!

/*******************************************************************************
<func>
Class:		CalcWindow
Function:	static CalcWindow *Instantiate(BMessage *archive);
Summary:	Constructor.
Params:		archive		message containing class data
Returns:	pointer to new'ed CalcWindow class. 
Author:		timmy
Created:	1997.10.14
Notes:		See BeBook/SupportKit/BArchivable for reference.
History:	-
</func>
*******************************************************************************/
CalcWindow *CalcWindow::Instantiate(BMessage *archive){ 

	if (!validate_instantiation(archive, "CalcWindow"))
		return NULL; 
	return new CalcWindow(archive);
	
} // end CalcWindow::Instantiate()


/*******************************************************************************
<func>
Class:		CalcWindow
Function:	CalcWindow(BRect frame, const char *title, const char *calcDesc);
Summary:	Constructor.
Params:		frame		onscreen window area rectangle
			title		window label text
			calcDesc	calculator desciption string
Author:		timmy
Created:	1997.10.02
History:
1997.10.05 timmy Now makes mCalcView the initial focus of the window.
1997.10.18 timmy Removed pop-up menu initialisation (now in CalcView).
</func>
*******************************************************************************/
CalcWindow::CalcWindow(BRect frame, const char *title, const char *calcDesc)
	:	BWindow(frame, title, B_TITLED_WINDOW, 0),
		mCalcView(NULL)
		{
	
	// create calculator view with calculator description
	frame.OffsetTo(B_ORIGIN);
	rgb_color calcBaseColor = {51, 102, 152, 255};
	mCalcView = new CalcView(frame, calcDesc, calcBaseColor);
	
	// create parent replicant view
	frame.top = frame.bottom - 7.0f;
	frame.left = frame.right - 7.0f;
	mDragger = new BDragger(frame, mCalcView,
		B_FOLLOW_RIGHT | B_FOLLOW_BOTTOM);
	
	// attach views
	AddChild(mCalcView);
	mCalcView->AddChild(mDragger);
	mCalcView->MakeFocus();
	
} // end CalcWindow::CalcWindow()


/*******************************************************************************
<func>
Class:		CalcWindow
Function:	CalcWindow(BMessage *archive);
Summary:	Construct from archive.
Params:		archive
Author:		timmy
Created:	1997.10.14
Notes:		See BeBook/SupportKit/BArchivable for reference.
History:
1997.10.18 timmy Removed pop-up menu initialisation (now in CalcView).
1998.11.07 timmy Parent BWindow now instantiates our view for us.
</func>
*******************************************************************************/
CalcWindow::CalcWindow(BMessage *archive)
	:	BWindow(archive)
		{
	
/*
	// read CalcView
	BMessage calcViewArchive;
	archive->FindMessage("calcView", &calcViewArchive);
	mCalcView = CalcView::Instantiate(&calcViewArchive);
	if (!mCalcView){
		// bogus, dude!
		puts("CalcView::Instantiate() failed.\n");
		exit(EXIT_FAILURE);
		} // end if
	
	// instantiate and attach calcView
	AddChild(mCalcView);
	mCalcView->MakeFocus();
*/
	
} // end CalcWindow::CalcWindow()

 
/*******************************************************************************
<func>
Class:		CalcWindow
Function:	virtual ~CalcWindow();
Summary:	Destructor.
Author:		timmy
Created:	1997.10.02
History:	-
</func>
*******************************************************************************/
CalcWindow::~CalcWindow(){

	// nothing to do...

} // end CalcWindow::~CalcWindow()


/*******************************************************************************
<func>
Class:		CalcWindow
Function:	virtual void MessageReceived(BMessage *message);
Summary:	Message received hook.
Params:		message		the incoming message
Author:		timmy
Created:	1997.10.14
History:
1998.07.26 timmy Updated for R3 mwcc compiler.
</func>
*******************************************************************************/
void CalcWindow::MessageReceived(BMessage *message){

	puts("window gets message!\n");

	switch (message->what){
	
		case B_MOUSE_DOWN:
		puts("mouse down!\n");
		BWindow::MessageReceived(message);
		break;
		
		case B_KEY_DOWN:
		puts("key down!\n");
		BWindow::MessageReceived(message);
		break;
		
		default:
		BWindow::MessageReceived(message);
	
		} // end switch

} // end CalcWindow::MessageReceived()


/*******************************************************************************
<func>
Class:		CalcWindow
Function:	bool QuitRequested();
Summary:	Quit requested hook.
Returns:	true if window is prepared to quit
Author:		timmy
Created:	1997.10.02
History:	-
</func>
*******************************************************************************/
bool CalcWindow::QuitRequested(){

	// request application to quit
	be_app->PostMessage(B_QUIT_REQUESTED);
	
	// let the app close us!
	Hide();
	return(false);

} // end CalcWindow::QuitRequested()


/*******************************************************************************
<func>
Class:		CalcWindow
Function:	virtual void FrameResized(float width, float height);
Summary:	Window dimensions changed hook.
Params:		width		new width of window
			height		new 
Author:		timmy
Created:	1997.10.04
History:	-
</func>
*******************************************************************************/
void CalcWindow::FrameResized(float /*width*/, float /*height*/){
} // end CalcWindow::FrameResized()


/*******************************************************************************
<func>
Class:		CalcWindow
Function:	virtual status_t Archive(BMessage *archive, bool deep = true) const;
Summary:	Archive this window.
Params:		archive		message to write object into
			deep		archive child objects? (not used)
Returns:	Status of archive opertation.
Author:		timmy
Created:	1997.10.13
History:
1998.07.26 timmy Updated for R3 mwcc compiler.
1998.11.07 timmy Altered to allow the BWindow to archive our views for us.
</func>
*******************************************************************************/
status_t CalcWindow::Archive(BMessage *archive, bool /*deep*/) const {

	// passed on request to parent
	status_t ret;
	if ((ret = BWindow::Archive(archive, true)) < B_OK) return ret;

/*	// add CalcView
	BMessage calcViewArchive;
	status_t status;
	if ((status = mCalcView->Archive(&calcViewArchive, true)) == B_OK){
		archive->AddMessage("calcView", &calcViewArchive);
		} // end if
	else return status;
*/
	// all was well
	return B_OK;

} // end CalcWindow::Archive()


/******************************************************************************/

// end CalcWindow.cpp